from django.contrib.auth.decorators import login_required
from django.db.models import Q
from django.views.generic.base import TemplateView
from django.views.generic.edit import UpdateView
from django.views.generic.list import ListView
from django.core.urlresolvers import reverse_lazy

from .models import User


class ProfileView(TemplateView):
    template_name = 'aa/profile.html'


profile_view = login_required(ProfileView.as_view())


class ProfileContactEditView(UpdateView):
    model = User
    fields = ['phone', 'mobile', 'share_contact_details']
    success_url = reverse_lazy('profile-view')

    def get_object(self):
        return self.request.user


profile_contact_edit = login_required(ProfileContactEditView.as_view())


class MembersListView(ListView):
    paginate_by = 10

    def get_queryset(self):
        qs = User.objects.filter(is_active=True)
        if self.request.GET.get('q'):
            for part in self.request.GET.get('q').split():
                part = part.strip()
                if not part:
                    continue
                qs = qs.filter(Q(first_name__icontains=part) | Q(last_name__icontains=part))
        return qs


members_list_view = login_required(MembersListView.as_view())
